const express = require("express");
const compression = require("compression");
const app = express();
const Docker = require("dockerode");
const docker = new Docker();
const ws = require("express-ws")(app);
const cors = require("cors");
const { convert } = require("./docker/names");
app.use(cors());
app.use(compression());
app.use(express.json());

app.get("/", (_, res) => {
  res.send("Merhaba Dünya!");
});

app.get("/containers", (_, res) => {
  docker.listContainers({ all: true }, function (_, containers) {
    res.send(
      containers
        .filter(
          (c) =>
            c.Image.startsWith("nyxteam/oyunparki-small") ||
            c.Image.startsWith("nyxteam/oyunparki-full")
        )
        .map((c) => {
          c.Names[0] = convert(c.Names[0]);
          return c;
        })
    );
  });
});

app.get("/images", (_, res) => {
  docker.listImages(function (_, images) {
    res.send(
      images.filter(
        (i) =>
          i.RepoTags[0].startsWith("nyxteam/oyunparki-small") ||
          i.RepoTags[0].startsWith("nyxteam/oyunparki-full")
      ).length !== 0
    );
  });
});

app.post("/create", (req, res) => {
  require("./docker/controllers/create")(req, res);
});

app.post("/restart", (req, res) => {
  res.send(docker.getContainer(req.body.container).restart());
});

app.post("/stop", (req, res) => {
  const container = docker.getContainer(req.body.container);
  container
    .stop()
    .then(() => {
      res.status(200).end();
    })
    .catch(() => {
      res.status(500).end();
    });
});

app.post("/remove", (req, res) => {
  const container = docker.getContainer(req.body.container);
  container
    .remove({
      force: true,
    })
    .then(() => {
      res.status(200).end();
    })
    .catch(() => {
      res.status(500).end();
    });
});

require("./socket")(app);

app.listen(30000);

module.exports = app;
